==> kari-0.30.tar.gz: kari-0.30/alyson/alyson.c <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <string.h>
#include <gtk/gtk.h>
#include "utils.h"
#include "neve.h"
#include "lisa.h"
#include "smg.h"
#include "parser.h"
#include "init.h"
#include "menu.h"
#include "text.h"
#include "urlentry.h"
#include "alyson.h"
#include "chloe.h"
#include "url.h"

/* The following causes "common.h" to produce definitions of all the global
   variables, rather than just "extern" declarations of them. */
#define GLOBAL
#include "globals.h"

BrowserWindow *paula;

/*****************************************************************************
 * function  : main
 * arguments : argc and argv
 * results   : 
 * purpose   : startup YAWN.
 * caveats   : You may be disappointed by YAWN.
 ***************************************************************************** */

int
main (int argc, char **argv)
{

  GtkWidget *tiffani;
  GtkWidget *menubar;

  char *start_url, *body, *temp;
  int optind;
  int i;

  program_name = argv[0];

  gtk_init (&argc, &argv);
  optind = parse_opt (argc, argv);

  paula = xmalloc (sizeof (BrowserWindow));

  paula->title = xmalloc (strlen ("YAWN: you suck") + 1);
  strcpy (paula->title, "YAWN: you suck");

  paula->main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (paula->main_window, "text window");

  gtk_signal_connect (GTK_OBJECT (paula->main_window), "destroy",
		      (GtkSignalFunc) destroy_window,
		      &paula->main_window);
  gtk_signal_connect (GTK_OBJECT (paula->main_window), "delete_event",
		      (GtkSignalFunc) destroy_window,
		      &paula->main_window);

  gtk_container_border_width (GTK_CONTAINER (paula->main_window), 10);
  gtk_window_set_title (GTK_WINDOW (paula->main_window), "YAWN");
  gtk_widget_set_usize (paula->main_window, 800, 800);
  gtk_window_set_policy (GTK_WINDOW (paula->main_window), TRUE, TRUE, TRUE);

  tiffani = gtk_vbox_new (FALSE, 0);
  menubar = menu_init (paula);
  gtk_box_pack_start (GTK_BOX (tiffani), menubar, FALSE, FALSE, 0);
  gtk_widget_show (menubar);

  paula->url_entry = urlentry_init ();
  gtk_box_pack_start (GTK_BOX (tiffani), paula->url_entry, FALSE, FALSE, 0);
  gtk_widget_show (paula->url_entry);

  gtk_container_add (GTK_CONTAINER (paula->main_window), tiffani);
  gtk_widget_show (tiffani);

  gtk_window_add_accelerator_table (GTK_WINDOW (paula->main_window),
				    paula->accelerator_table);

  text_init (paula, tiffani);

  /* If there is no URL passed on the command line, use $WWW_HOME, if
   * it exists.  If it doesn't, default to the YAWN homepage. */

  if (optind == argc) 
    { 
      temp = getenv ("WWW_HOME");
      if (temp)
	{
	  start_url = xmalloc (strlen (temp) + 1);
	  strcpy (start_url, temp);
	}
      else 
	{
	  start_url = xmalloc (strlen ("http://yawn.nocrew.org/") + 1);
	  strcpy (start_url, "http://yawn.nocrew.org/");
	}
    } 
  else
    {
      start_url = xmalloc (strlen (argv[optind]) + 1);
      strcpy (start_url, argv[optind]);
    }

  i = parse_url (start_url, paula);
  
  if (i < 0)
    fubar (NONSYS, "parse_url died?  I'm not setup to cope with this.  I have _issues_.");
  
  body = get_html_file (paula);

  urlentry_update (paula->url_entry, start_url);

  gtk_widget_show (paula->main_window);

  parse_html (body, paula);
  free (body);

  gtk_main ();

  return 0;

}

/*****************************************************************************
 * function  : destroy_window
 * arguments : 
 * results   : 
 * purpose   : die.
 * caveats   : 
 ***************************************************************************** */

void
destroy_window (void)
{
  gtk_main_quit ();
}

/* This is a sucky procedure, with one goal; get round the fact that
 * the URL entry box has no idea which SMG it's tied to */

BrowserWindow *
help_me_bob (void)
{
  return paula;
}

==> kari-0.33.tar.gz: kari-0.33/alyson/alyson.c <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <james@nocrew.org>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <string.h>
#include <gtk/gtk.h>
#include "utils.h"
#include "neve.h"
#include "lisa.h"
#include "smg.h"
#include "parser.h"
#include "init.h"
#include "menu.h"
#include "text.h"
#include "urlentry.h"
#include "cameron.h"
#include "alyson.h"
#include "chloe.h"
#include "url.h"

/* The following causes "common.h" to produce definitions of all the global
   variables, rather than just "extern" declarations of them. */
#define GLOBAL
#include "globals.h"

BrowserWindow *paula;

/*****************************************************************************
 * function  : main
 * arguments : argc and argv
 * results   : 
 * purpose   : startup YAWN.
 * caveats   : You may be disappointed by YAWN.
 ***************************************************************************** */

int
main (int argc, char **argv)
{

  GtkWidget *tiffani;
  GtkWidget *menubar;
  char *start_url, *body, *temp;
  int optind;
  int i;

  program_name = argv[0];

  gtk_init (&argc, &argv);
  optind = parse_opt (argc, argv);

  paula = xmalloc (sizeof (BrowserWindow));

  paula->title = xmalloc (strlen ("YAWN: you suck") + 1);
  strcpy (paula->title, "YAWN: you suck");

  paula->main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (paula->main_window, "text window");

  gtk_signal_connect (GTK_OBJECT (paula->main_window), "destroy",
		      (GtkSignalFunc) destroy_window,
		      &paula->main_window);
  gtk_signal_connect (GTK_OBJECT (paula->main_window), "delete_event",
		      (GtkSignalFunc) destroy_window,
		      &paula->main_window);

  gtk_container_border_width (GTK_CONTAINER (paula->main_window), 10);
  gtk_window_set_title (GTK_WINDOW (paula->main_window), "YAWN");
  gtk_widget_set_usize (paula->main_window, 800, 800);
  gtk_window_set_policy (GTK_WINDOW (paula->main_window), TRUE, TRUE, TRUE);

  tiffani = gtk_vbox_new (FALSE, 0);
  menubar = menu_init (paula);
  gtk_box_pack_start (GTK_BOX (tiffani), menubar, FALSE, FALSE, 0);
  gtk_widget_show (menubar);

  paula->cameron = cameron_init ();
  gtk_box_pack_start (GTK_BOX (tiffani), paula->cameron, FALSE, FALSE, 0);
  gtk_widget_show (paula->cameron);

  paula->url_entry = urlentry_init ();
  gtk_box_pack_start (GTK_BOX (tiffani), paula->url_entry, FALSE, FALSE, 0);
  gtk_widget_show (paula->url_entry);

  gtk_container_add (GTK_CONTAINER (paula->main_window), tiffani);
  gtk_widget_show (tiffani);

  gtk_window_add_accelerator_table (GTK_WINDOW (paula->main_window),
				    paula->accelerator_table);

  text_init (paula, tiffani);
  gtk_widget_grab_focus (paula->lisa);

  /* If there is no URL passed on the command line, use $WWW_HOME, if
   * it exists.  If it doesn't, default to the YAWN homepage. */

  if (optind == argc) 
    { 
      temp = getenv ("WWW_HOME");
      if (temp)
	{
	  start_url = xmalloc (strlen (temp) + 1);
	  strcpy (start_url, temp);
	}
      else 
	{
	  start_url = xmalloc (24);
	  strcpy (start_url, "http://yawn.nocrew.org/");
	}
    } 
  else
    {
      start_url = xmalloc (strlen (argv[optind]) + 1);
      strcpy (start_url, argv[optind]);
    }

  start_url = dehumanize_url (start_url);

  urlentry_update (paula->url_entry, start_url);

  gtk_widget_show (paula->main_window);

  /* Flush all GTK events before going off to retrieve the first file */

  while (gtk_events_pending())
    gtk_main_iteration();

  /* Get the inital file */
  
  i = parse_url (start_url, paula);
  if (i >= 0)
    {
      body = get_html_file (paula);
      if (body)
	{
	  lisa_set_default_colours(GTK_LISA(paula->lisa));
	  parse_html (body, paula);
	  free (body);
	}
    }

  gtk_main ();

  return 0;

}

void
destroy_window (void)
{
  gtk_main_quit ();
}

/* This is a sucky procedure, with one goal; get round the fact that
 * the URL entry box has no idea which SMG it's tied to */

BrowserWindow *
help_me_bob (void)
{
  return paula;
}
